package com.chelvc.cloud.admin.controller;

import com.chelvc.cloud.vehicle.api.dto.CouponActivityDTO;
import com.chelvc.cloud.vehicle.api.param.CouponActivityModifyParam;
import com.chelvc.cloud.vehicle.api.param.CouponActivityPagingParam;
import com.chelvc.cloud.vehicle.api.service.CouponActivityService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.util.ResourceUtils;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.Min;

/**
 * 优惠券活动接口
 *
 * @author qizaqi
 * @Date 2023/11/10
 **/
@Validated
@RestController
@ResponseWrapping
@PreAuthorize("isScope('EMPLOYEE')")
public class CouponActivityController {
    @DubboReference
    private CouponActivityService couponActivityService;

    /**
     * 新增优惠券活动
     *
     * @param param 新增参数
     * @return 优惠券活动主键
     */
    @PostMapping("/couponActivity")
    public Long addCouponActivity(@RequestBody @Valid CouponActivityModifyParam param) {
        return this.couponActivityService.addCouponActivity(param);
    }

    /**
     * 修改优惠券活动
     *
     * @param id    商品优惠券主键
     * @param param 修改参数
     */
    @PutMapping("/couponActivity/{id}")
    public void updateCouponActivity(@PathVariable("id") @Min(value = 1, message = "优惠券活动主键不能小于1") Long id,
                               @RequestBody @Valid CouponActivityModifyParam param) {
        this.couponActivityService.updateCouponActivity(id, param);
    }

    /**
     * 删除优惠券活动
     *
     * @param id    优惠券活动主键
     */
    @PutMapping("/couponActivity/delete/{id}")
    public void deleteCouponActivity(@PathVariable("id") @Min(value = 1, message = "优惠券活动主键不能小于1") Long id) {
        this.couponActivityService.deleteCouponActivity(id);
    }

    /**
     * 查询优惠券活动分页
     *
     * @param param 查询参数
     * @return 优惠券活动分页信息
     */
    @GetMapping("/couponActivity/paging")
    public Pagination<CouponActivityDTO> getCouponActivityPaging(@Valid CouponActivityPagingParam param) {
        return this.couponActivityService.getCouponActivityPaging(param);
    }

    /**
     * 获取优惠券活动信息
     *
     * @param id 优惠券活动主键
     * @return 优惠券活动信息
     */
    @GetMapping("/couponActivity/{id}")
    public CouponActivityDTO getEmployee(@PathVariable("id") @Min(value = 1, message = "优惠券活动主键不能小于1") Long id) {
        return ResourceUtils.required(this.couponActivityService.getCouponActivity(id), "优惠券活动不存在");
    }
}
